.. AUTOMATICALLY GENERATED FILE!
.. Edit the templates ``*.jinja``, the header files ``*.cl``, or the model
.. definitions in ``models/`` instead, then run the ``prepare.py``
.. script in the main directory.


Bar & Eiswirth 1993
===================

**Key:** ``bar1993turbulence``

This simple two-variable model was created by modifying the model by FitzHugh
& Nagumo to describe cardiac excitation waves. This model shows that spiral breakup,
leading to turbulence, can occur in a two-dimensional reaction-diffusion system with
delayed-inhibitor production.

References
----------

1. https://doi.org/10.1103/PhysRevE.48.R1635



Variables
---------

0. ``u = 0.0``
1. ``v = 0.0``

Parameters
----------

- ``diffusivity_u = 1.0``
- ``eps = 0.075``
- ``a = 0.84``
- ``b = 0.07``

Source code
-----------
.. raw:: html

    <details>
    <summary>OpenCL kernel</summary>

.. code-block:: c

    const Real _react_u = - u * (u - 1.0) * (u - ((v + b)/a) )/eps;
    const Real f = (u < 1.0/3.0) ? 0.0 : (u > 1.0) ? 1.0 : (1 - 6.75*u*(u - 1)*(u - 1));
    const Real _react_v = f - v;
    *_new_u = u + dt * (_react_u + _diffuse_u);
    *_new_v = v + dt * _react_v;

.. raw:: html

    </details>

Additional metadata
-------------------

.. code-block:: yaml

    keywords:
    - excitable media
    - electrophysiology
    - heart
    - phenomenological
